{% extends "admin_base.html" %}

{% import "admin_page.html" as pg %}
{% block content %}
    <div class="wrap js-check-wrap">
        <ul class="nav nav-tabs">
            <li class="active"><a href="javascript:;">运行记录</a></li>
        </ul>
        <form method="post" class="js-ajax-form" action="">
            <table class="table table-hover table-bordered">
                <thead>
                <tr>
                    <th>编号</th>
                    <th>返回的内容</th>
                    <th>执行时间</th>
                    <th>耗时</th>
                    <th>更详细的执行记录</th>
                </tr>
                </thead>
                <tbody>
                    {% for item in page_data.items %}
                    <tr>
                        <td>{{ item.id }}</td>
                        <td>{{ item.content }}</td>
                        <td>{{ item.create_time }}</td>
                        <td>{{ item.take_time }}</td>
                        <td><a href="javascript:;" onclick="open_iframe_dialog('{{ url_for('main.job_log_item_list',log_id=item.log_id) }}','详细执行记录',{width: '80%',
        height: '80%'})">查看</a></td>
                    </tr>
                {% endfor %}
                </tbody>
            </table>
        </form>
     <div class="pagination">
            {{ pg.page(page_data,'main.job_log_list',keywords) }}
        </div>
    </div>
{% endblock %}