<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>密码输入</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- 最新版本的 Bootstrap 核心 CSS 文件 -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@3.3.7/dist/css/bootstrap.min.css" integrity="sha384-BVYiiSIFeK1dGmJRAkycuHAHRg32OmUcww7on3RYdg4Va+PmSTsz/K68vbdEjh4u" crossorigin="anonymous">

    <!-- 可选的 Bootstrap 主题文件（一般不用引入） -->
{#    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@3.3.7/dist/css/bootstrap-theme.min.css" integrity="sha384-rHyoN1iRsVXV4nD0JutlnGaslCJuC7uwjduW9SVrLvRYooPp2bWYgmgJQIXwl/Sp" crossorigin="anonymous">#}
    <script src="{{ url_for('static',filename='js/jquery.js') }}"></script>
    <!-- 最新的 Bootstrap 核心 JavaScript 文件 -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@3.3.7/dist/js/bootstrap.min.js" integrity="sha384-Tc5IQib027qvyjSMfHjOMaLkfuWVxZxUPnCJA7l2mCWNIpG9mGCD8wGNIcPD7Txa" crossorigin="anonymous"></script>
    <script src="https://cdn.staticfile.org/jquery-cookie/1.4.1/jquery.cookie.min.js"></script>
    <style>
        .zt{
            color: orange;
            font-size: 1.4em;
        }
        #qrcode {
            width:100px;
            height:100px;
        }
    </style>
</head>
<body>
<div class="jumbotron" style="background-color: white;">
            <div style="text-align: center">
                <h1 class="display-4">小牛定时任务管理系统</h1>
                <p class="lead">&nbsp;&nbsp;方便、统一、自由</p>
            </div>
        </div>
<div style="text-align: center">
<form action="{{ url_for('main.check_pass') }}" method="post" class="well form-search form-inline">
    <input type="text" name="password" value="" placeholder="密码" class="form-control"> <input type="submit" value="确定" class="btn btn-primary">
    <br>当前系统时间: {{ today }}
</form>
    {% if msg %}
<div style="text-align: center;font-size: 1.2em;color: red">
       {{ msg }}
    </div>
{% endif %}
</div>
</body>
</html>